package uraxis.programnodes;

import com.ur.urcap.api.contribution.ProgramNodeContribution;
import com.ur.urcap.api.contribution.program.ProgramAPIProvider;
import com.ur.urcap.api.domain.ProgramAPI;
import com.ur.urcap.api.domain.data.DataModel;
import com.ur.urcap.api.domain.script.ScriptWriter;
import com.ur.urcap.api.domain.undoredo.UndoRedoManager;
import com.ur.urcap.api.domain.undoredo.UndoableChanges;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardInputCallback;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardInputFactory;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardNumberInput;
import com.ur.urcap.api.domain.userinteraction.keyboard.KeyboardTextInput;
import uraxis.MyDaemonInstallationNodeContribution;

public class AbsoluteNodeContribution implements ProgramNodeContribution {

    private final ProgramAPI programAPI;
    private final UndoRedoManager undoRedoManager;
    private final KeyboardInputFactory keyboardFactory;

    private final AbsoluteNodeView view;
    private final DataModel model;

    public AbsoluteNodeContribution(ProgramAPIProvider apiProvider, AbsoluteNodeView view, DataModel model) {
        this.programAPI = apiProvider.getProgramAPI();
        this.undoRedoManager = apiProvider.getProgramAPI().getUndoRedoManager();
        this.keyboardFactory = apiProvider.getUserInterfaceAPI().getUserInteraction().getKeyboardInputFactory();

        this.view = view;
        this.model = model;
    }

    @Override
    public void openView() {
        view.setPopupText(0);
    }

    @Override
    public void closeView() {
    }

    @Override
    public String getTitle() {
        return "Hello World Swing: ";
    }


    @Override
    public void generateScript(ScriptWriter writer) {
        // Directly generate this Program Node's popup message + access the popup title through a global variable
        writer.appendLine("popup(\"" + "generatePopupMessage()" + "\", hello_world_swing_popup_title, False, False, blocking=True)");
        writer.writeChildren();
    }

    public KeyboardNumberInput getKeyboardForTextField() {
        KeyboardNumberInput<Integer> keyboardInput = keyboardFactory.createIntegerKeypadInput();
        keyboardInput.setInitialValue(0);
        return keyboardInput;
    }

    public KeyboardInputCallback<Integer> getCallbackForTextField() {
        return new KeyboardInputCallback<Integer>() {
            @Override
            public void onOk(Integer value) {
                view.setPopupText(value);
            }
        };
    }

    private MyDaemonInstallationNodeContribution getInstallation() {
        return programAPI.getInstallationNode(MyDaemonInstallationNodeContribution.class);
    }

    @Override
    public boolean isDefined() {
        return true;
    }
}
